@@ -117,12 +117,16 @@ def _deepcopy(config):
 def _gen_parser(parser_conf, subparser=False):
     """Retrieve arguments pass to **argparse.ArgumentParser** from
     **parser_conf**. A subparser can take an extra 'help' keyword."""
+    #formatter = parser_conf.get('formatter_class', 'HelpFormatter')
+    #formatter_class = (lambda prog:
+    #    getattr(argparse, formatter)(prog, max_help_position=35, width=80))
     formatter_class = parser_conf.get('formatter_class', 'HelpFormatter')
     conf = {'prog': parser_conf.get('prog', None),
             'usage': None,
             'description': parser_conf.get('description', None),
             'epilog': parser_conf.get('epilog', None),
             'formatter_class':  getattr(argparse, formatter_class),
+            #'formatter_class':  formatter_class,
             'argument_default': parser_conf.get('argument_default', None),
             'conflict_handler': parser_conf.get('conflict_handler', 'error'),
             'add_help': parser_conf.get('add_help', True)}
@@ -223,7 +227,8 @@ def _check_keywords(path, conf, section, one=None, need=None):
     for keyword in conf:
         if keyword not in valid_keywords:
             raise CLGError(path, _INVALID_KEYWORD.format(keyword=keyword))
-        _check_empty(path + [keyword], conf[keyword])
+        if keyword != 'default':
+            _check_empty(path + [keyword], conf[keyword])
 
     if one and len([arg for arg in conf if arg in one]) != 1:
         raise CLGError(path, _ONE_KEYWORDS.format(keywords="', '".join(one)))
@@ -256,7 +261,10 @@ def _has_value(value, conf):
     action = conf.get('action', None)
     return ((not action and value) or
             (action and action == 'store_true' and value) or
-            (action and action == 'store_false' and not value))
+            (action and action == 'store_false' and not value) or
+            # Manage boolean values like BooleanOptional action
+            (isinstance(value, bool) and value))
+
 
 def _post_need(parser, parser_args, args_values, arg):
     """Post processing that check all for needing options."""
@@ -782,7 +790,8 @@ class CommandLine(object):
 
 
 def init(format='yaml', data=os.path.join(sys.path[0], 'cmd.yml'),
-         completion=False, subcommands_keyword='command', deepcopy=True):
+         completion=False, subcommands_keyword='command', deepcopy=True,
+         args=None):
     """Wrapping method that initialize the command-line and export the input
     configuration and the **CommandLine** object at the module level.
 
@@ -818,6 +827,4 @@ def init(format='yaml', data=os.path.join(sys.path[0], 'cmd.yml'),
     setattr(_SELF, 'cmd', cmd)
 
     # Parse arguments.
-    args = cmd.parse()
-
-    return args
+    return cmd.parse(args)
